==> apache-shenyu-2.5.0-src.zip: apache-shenyu-2.5.0-src/shenyu-common/src/test/java/org/apache/shenyu/common/utils/ReflectUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.utils;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

/**
 * Test cases for ReflectUtils.
 */
public final class ReflectUtilsTest {

    @Test
    public void testGetFieldValue() {
        final Reflect reflect = new Reflect();
        final ReflectNonField reflectNonField = new ReflectNonField();
        assertEquals("1", ReflectUtils.getFieldValue(reflect, "a"));
        assertNull(ReflectUtils.getFieldValue(reflect, ""));
        assertNull(ReflectUtils.getFieldValue(null, "a"));
        assertNull(ReflectUtils.getFieldValue(reflectNonField, "a"));
    }

    @Test
    public void testSetFieldValue() {
        final Reflect reflect = new Reflect();
        ReflectUtils.setFieldValue(reflect, "a", "2");
        assertEquals("2", ReflectUtils.getFieldValue(reflect, "a"));
    }

    static class Reflect {
        private final String a = "1";
    }

    static class ReflectNonField {
    }
}

==> apache-shenyu-2.7.0.3-src.zip: apache-shenyu-2.7.0.3-src/shenyu-common/src/test/java/org/apache/shenyu/common/utils/ReflectUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.utils;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Test cases for ReflectUtils.
 */
public final class ReflectUtilsTest {

    @Test
    public void testGetFieldValue() {
        final Reflect reflect = new Reflect();
        final ReflectNonField reflectNonField = new ReflectNonField();
        assertEquals("1", ReflectUtils.getFieldValue(reflect, "a"));
        assertNull(ReflectUtils.getFieldValue(reflect, ""));
        assertNull(ReflectUtils.getFieldValue(null, "a"));
        assertNull(ReflectUtils.getFieldValue(reflectNonField, "a"));
    }

    @Test
    public void testSetFieldValue() {
        final Reflect reflect = new Reflect();
        ReflectUtils.setFieldValue(reflect, "a", "2");
        assertEquals("2", ReflectUtils.getFieldValue(reflect, "a"));
    }

    @Test
    public void testInvokeStaticMethod() {
        final Reflect reflect = new Reflect();
        assertEquals("1", ReflectUtils.invokeStaticMethod(reflect.getClass(), "methodStaticA"));
        assertNull(ReflectUtils.invokeStaticMethod(reflect.getClass(), "methodB"));
    }

    @Test
    public void testInvokeMethod() {
        final Reflect reflect = new Reflect();
        assertEquals("1", ReflectUtils.invokeMethod(reflect, "methodA"));
    }

    @Test
    public void testIsPrimitives() {
        final Reflect reflect = new Reflect();
        Integer[] test = new Integer[]{};
        assertFalse(ReflectUtils.isPrimitives(reflect.getClass()));
        assertFalse(ReflectUtils.isPrimitives(reflect.getClass()));
        assertTrue(ReflectUtils.isPrimitives(test.getClass()));
    }

    static class Reflect {
        private final String a = "1";

        public static String methodStaticA() {
            return "1";
        }

        public String methodA() {
            return "1";
        }
    }

    static class ReflectNonField {
    }
}
